@@ -12,25 +12,25 @@
 // $ export RUST_LOG=mwalib=debug
 //
 use anyhow::*;
-use structopt::StructOpt;
+use clap::Parser;
 
 use mwalib::*;
 
-#[derive(StructOpt, Debug)]
-#[structopt(name = "mwalib-print-obs-context", author)]
+#[derive(Parser, Debug)]
+#[clap(name = "mwalib-print-obs-context", author)]
 struct Opt {
     /// The path to an observation's metafits file.
-    #[structopt(short, long, parse(from_os_str))]
+    #[clap(short, long, parse(from_os_str))]
     metafits: std::path::PathBuf,
 
     /// Paths to the observation's gpubox files.
-    #[structopt(name = "GPUBOX FILE", parse(from_os_str))]
+    #[clap(name = "GPUBOX FILE", parse(from_os_str))]
     files: Vec<std::path::PathBuf>,
 }
 
 fn main() -> Result<(), anyhow::Error> {
     env_logger::try_init().unwrap_or(());
-    let opts = Opt::from_args();
+    let opts = Opt::parse();
     let context = CorrelatorContext::new(&opts.metafits, &opts.files)?;
 
     println!("{}", context);
