@@ -123,18 +123,11 @@ fn test_process_coarse_chans_vcs_legacy_middle_two_channels() {
         assert_eq!(coarse_chan_array.len(), 2);
         assert_eq!(coarse_chan_array[0].corr_chan_number, 1);
         assert_eq!(coarse_chan_array[0].rec_chan_number, 110);
-        if mwa_version == MWAVersion::VCSLegacyRecombined {
-            assert_eq!(coarse_chan_array[0].gpubox_number, 2);
-        } else {
-            assert_eq!(coarse_chan_array[0].gpubox_number, 110);
-        }
+        assert_eq!(coarse_chan_array[0].gpubox_number, 110);
+
         assert_eq!(coarse_chan_array[1].corr_chan_number, 2);
         assert_eq!(coarse_chan_array[1].rec_chan_number, 111);
-        if mwa_version == MWAVersion::VCSLegacyRecombined {
-            assert_eq!(coarse_chan_array[1].gpubox_number, 3);
-        } else {
-            assert_eq!(coarse_chan_array[1].gpubox_number, 111);
-        }
+        assert_eq!(coarse_chan_array[1].gpubox_number, 111);
     }
 }
 
@@ -216,19 +209,19 @@ fn test_process_coarse_chans_vcs_legacy_chan_reversal() {
     assert_eq!(coarse_chan_array.len(), 5);
     assert_eq!(coarse_chan_array[0].corr_chan_number, 0);
     assert_eq!(coarse_chan_array[0].rec_chan_number, 126);
-    assert_eq!(coarse_chan_array[0].gpubox_number, 1);
+    assert_eq!(coarse_chan_array[0].gpubox_number, 126);
     assert_eq!(coarse_chan_array[1].corr_chan_number, 1);
     assert_eq!(coarse_chan_array[1].rec_chan_number, 127);
-    assert_eq!(coarse_chan_array[1].gpubox_number, 2);
+    assert_eq!(coarse_chan_array[1].gpubox_number, 127);
     assert_eq!(coarse_chan_array[2].corr_chan_number, 2);
     assert_eq!(coarse_chan_array[2].rec_chan_number, 128);
-    assert_eq!(coarse_chan_array[2].gpubox_number, 3);
+    assert_eq!(coarse_chan_array[2].gpubox_number, 128);
     assert_eq!(coarse_chan_array[3].corr_chan_number, 4);
     assert_eq!(coarse_chan_array[3].rec_chan_number, 129);
-    assert_eq!(coarse_chan_array[3].gpubox_number, 5);
+    assert_eq!(coarse_chan_array[3].gpubox_number, 129);
     assert_eq!(coarse_chan_array[4].corr_chan_number, 3);
     assert_eq!(coarse_chan_array[4].rec_chan_number, 130);
-    assert_eq!(coarse_chan_array[4].gpubox_number, 4);
+    assert_eq!(coarse_chan_array[4].gpubox_number, 130);
 }
 
 #[test]
@@ -326,7 +319,7 @@ fn test_process_coarse_chans_corr_legacy_first_and_last() {
 /// 110 == missing
 /// 111 == missing
 /// 112 == index 3
-fn test_process_coarse_chans_vcs_legacy_first_and_last() {
+fn test_process_coarse_chans_vcs_legacy_mwax_first_and_last() {
     test(MWAVersion::VCSLegacyRecombined);
     test(MWAVersion::VCSMWAXv2);
 
@@ -353,20 +346,11 @@ fn test_process_coarse_chans_vcs_legacy_first_and_last() {
         assert_eq!(coarse_chan_array.len(), 2);
         assert_eq!(coarse_chan_array[0].corr_chan_number, 0);
         assert_eq!(coarse_chan_array[0].rec_chan_number, 109);
-        if mwa_version == MWAVersion::VCSLegacyRecombined {
-            assert_eq!(coarse_chan_array[0].gpubox_number, 1);
-        } else {
-            assert_eq!(coarse_chan_array[0].gpubox_number, 109);
-        }
+        assert_eq!(coarse_chan_array[0].gpubox_number, 109);
 
         assert_eq!(coarse_chan_array[1].corr_chan_number, 3);
         assert_eq!(coarse_chan_array[1].rec_chan_number, 112);
-
-        if mwa_version == MWAVersion::VCSLegacyRecombined {
-            assert_eq!(coarse_chan_array[1].gpubox_number, 4);
-        } else {
-            assert_eq!(coarse_chan_array[1].gpubox_number, 112);
-        }
+        assert_eq!(coarse_chan_array[1].gpubox_number, 112);
     }
 }
 
