@@ -85,7 +85,7 @@ fn test_read_metafits_values_from_row_0() {
 
     // Get values from row 1
     let row: RfInputMetafitsTableRow =
-        Rfinput::read_metafits_values(&mut metafits_fptr, &metafits_tile_table_hdu, 0).unwrap();
+        Rfinput::read_metafits_values(&mut metafits_fptr, &metafits_tile_table_hdu, 0, 24).unwrap();
     assert_eq!(row.input, 0);
     assert_eq!(row.antenna, 75);
     assert_eq!(row.tile_id, 104);
@@ -139,7 +139,7 @@ fn test_read_metafits_values_from_invalid_metafits() {
 
         // Get values from row 1
         let metafits_result =
-            Rfinput::read_metafits_values(metafits_fptr, &metafits_tile_table_hdu, 0);
+            Rfinput::read_metafits_values(metafits_fptr, &metafits_tile_table_hdu, 0, 24);
 
         assert!(metafits_result.is_err());
     });
@@ -157,7 +157,7 @@ fn test_populate_rf_inputs() {
     let mut metafits_fptr = fits_open!(&metafits_filename).unwrap();
     let metafits_tile_table_hdu = fits_open_hdu!(&mut metafits_fptr, 1).unwrap();
     let result =
-        Rfinput::populate_rf_inputs(256, &mut metafits_fptr, metafits_tile_table_hdu, 1.204);
+        Rfinput::populate_rf_inputs(256, &mut metafits_fptr, metafits_tile_table_hdu, 1.204, 24);
 
     assert!(result.is_ok());
 
@@ -194,13 +194,28 @@ fn test_populate_rf_inputs() {
         float_cmp::F64Margin::default()
     ));
     assert!(rfinput[0].flagged);
-    assert_eq!(
-        rfinput[0].digital_gains,
-        vec![
-            74, 73, 73, 72, 71, 70, 68, 67, 66, 65, 65, 65, 66, 66, 65, 65, 64, 64, 64, 65, 65, 66,
-            67, 68
-        ]
-    );
+
+    assert!(float_cmp::approx_eq!(
+        f64,
+        rfinput[0].digital_gains[0],
+        74. / 64.,
+        float_cmp::F64Margin::default()
+    ));
+
+    assert!(float_cmp::approx_eq!(
+        f64,
+        rfinput[0].digital_gains[12],
+        66. / 64.,
+        float_cmp::F64Margin::default()
+    ));
+
+    assert!(float_cmp::approx_eq!(
+        f64,
+        rfinput[0].digital_gains[23],
+        68. / 64.,
+        float_cmp::F64Margin::default()
+    ));
+    
     assert_eq!(
         rfinput[0].dipole_delays,
         vec![0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]
